Batchwise
*********

Trainer
-------

.. autoxpmconfig:: xpmir.letor.trainers.batchwise.BatchwiseTrainer

Losses
------

.. autoxpmconfig:: xpmir.letor.trainers.batchwise.BatchwiseLoss
.. autoxpmconfig:: xpmir.letor.trainers.batchwise.CrossEntropyLoss
.. autoxpmconfig:: xpmir.letor.trainers.batchwise.SoftmaxCrossEntropy

Samplers
--------

.. currentmodule:: xpmir.letor.samplers


.. autoxpmconfig:: BatchwiseSampler

.. autoxpmconfig:: xpmir.documents.samplers.RandomSpanSampler
